#
# spec file for package Komikku
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         appid info.febvre.Komikku
Name:           Komikku
Version:        1.80.0
Release:        1.1
Summary:        A manga reader for GNOME
# appdata.xml is CC-BY-4.0
License:        CC-BY-4.0 AND GPL-3.0-or-later
URL:            https://codeberg.org/valos/Komikku
Source0:        %{url}/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  desktop-file-utils
BuildRequires:  fdupes
BuildRequires:  gettext
BuildRequires:  intltool
BuildRequires:  meson >= 0.59.0
BuildRequires:  python3-devel
BuildRequires:  python3-gobject
BuildRequires:  pkgconfig(appstream-glib)
BuildRequires:  pkgconfig(blueprint-compiler)
BuildRequires:  pkgconfig(gobject-introspection-1.0) >= 1.35.9
BuildRequires:  pkgconfig(gtk4)
BuildRequires:  pkgconfig(libadwaita-1) >= 1.7
BuildRequires:  pkgconfig(libnotify)
BuildRequires:  pkgconfig(python3)
Requires:       WebKitGTK-6.0
Requires:       python3-Brotli >= 1.1.0
Requires:       python3-Pillow >= 10.3.0
Requires:       python3-Unidecode
Requires:       python3-beautifulsoup4
Requires:       python3-cffi
Requires:       python3-cloudscraper
Requires:       python3-cryptography
Requires:       python3-dateparser >= 1.1.6
Requires:       python3-emoji
Requires:       python3-gobject
Requires:       python3-keyring >= 21.6.0
Requires:       python3-lxml >= 5.2.1
Requires:       python3-modern-colorthief >= 0.1.3
Requires:       python3-natsort >= 7.1.1
Requires:       python3-piexif
Requires:       python3-pillow-heif >= 0.16.0
Requires:       python3-pure-protobuf >= 3.0.0
Requires:       python3-pycairo
Requires:       python3-python-magic
Requires:       python3-pytz
Requires:       python3-rarfile
Requires:       python3-regex
Requires:       python3-requests >= 2.32.2
Requires:       python3-setuptools-gettext
Requires:       python3-typing_extensions
Requires:       python3-tzlocal
Requires:       python3-urllib3
Requires:       python3-wheel
Requires:       unrar_wrapper
BuildArch:      noarch

%description
Komikku is a manga reader for GNOME. It focuses on providing a clean, intuitive
and adaptive interface.

Keys features
* Online reading from dozens of servers
* Offline reading of downloaded comics
* Categories to organize your library
* RTL, LTR, Vertical and Webtoon reading modes
* Several types of navigation:
  * Keyboard arrow keys
  * Right and left navigation layout via mouse click or tapping
    (touchpad/touch screen)
  * Mouse wheel
  * 2-fingers swipe gesture (touchpad)
  * Swipe gesture (touch screen)
* Automatic update of comics
* Automatic download of new chapters
* Reading history
* Light and dark themes

%lang_package

%prep
%autosetup -p1 -n komikku

%build
%meson
%meson_build

%install
%meson_install
%fdupes %{buildroot}

%find_lang komikku

%check
%meson_test

%files
%license LICENSES/*
%doc README.md CONTRIBUTING.md
%{_bindir}/komikku
%{_datadir}/applications/%{appid}.desktop
%{_datadir}/glib-2.0/schemas/%{appid}.gschema.xml
%{_datadir}/icons/hicolor/scalable/apps/%{appid}.svg
%{_datadir}/icons/hicolor/symbolic/apps/%{appid}-symbolic.svg
%{_datadir}/metainfo/%{appid}.appdata.xml
%{_datadir}/komikku
%{_datadir}/dbus-1/services/%{appid}.service
%{python_sitelib}/komikku

%files lang -f komikku.lang

%changelog
* Fri Jun 20 2025 Richard Rahl <rrahl0@opensuse.org>
- update to 1.80.0:
  * [Card] Pool-to-Update: Improved spinner visibility
  * [Servers] Added ComicK (comick.io)
  * [Servers] Added Raijin Scan (FR)
  * [Servers] Pepper & Carrot: Update
  * [Servers] Phenix Scans (FR): Update
  * [Servers] Mangalek (AR): Update
  * [Servers] Tres Daos (ES): Update
  * [Servers] WEBTOON (EN/ES/FR/ID/TH/ZH): Update
  * [L10n] Updated French and Persian translations
* Sat Jun  7 2025 Richard Rahl <rrahl0@opensuse.org>
- update to 1.79.1:
  * [Card] Fixed Pull-to-Update
- update to 1.79.0:
  * [Card] Added new backdrop method: Blurred cover
  * [Servers] Dragon Ball Multiverse: Update
  * [Servers] EZmanga (EN): Update
  * [Servers] MangaCrab (ES): Update
  * [Servers] MangaMana (FR): Update
  * [Servers] MangaNato (EN): Update
  * [Servers] Mangaowl (EN): Update
  * [Servers] MangaReader (cc) (EN): Update
  * [Servers] Neko Scans(ES): Update
  * [Servers] Pepper&Carrot: Added support of Persian language
  * [Servers] Rawdevart (JA): Update
  * [Servers] Read Comic Online (EN): Update
  * [Servers] Senpai Ediciones (ES): Disabled
  * [Servers] Terco Scans (EN): Update
  * [Servers] Usagi (RU): Disabled
  * [L10n] Updated Arabic and Persian translations
* Fri May 30 2025 Richard Rahl <rrahl0@opensuse.org>
- update to 1.78.0:
  * [Card] Details page: Redesign
  * [Servers] Local: Added support of CBT archive format (TAR)
  * [Servers] Added Blue Solo (FR)
  * [Servers] SMBC (EN): Re-enabled
  * [Servers] Poseidon Scans (FR): Disabled
  * [L10n] Updated Arabic, Bulgarian, Catalan and Portuguese translations
* Sat May 24 2025 Richard Rahl <rrahl0@opensuse.org>
- update to 1.77.0:
  * [Webview] Fixed Cloudflare challenge detection
  * [Servers] Manga-Scantrad (FR): Update
  * [Servers] Night scans (EN): Update
  * [Servers] Tres Daos (ES): Update
  * [Servers] Mangapill (EN): Update
  * [L10n] Updated Spanish translation
* Fri May  9 2025 Richard Rahl <rrahl0@opensuse.org>
- update to 1.76.1:
  * [Reader] Webtoon mode: Fixed scrolling after a pages jump
    (using controls overlay)
  * [L10n] Updated Portuguese (Brazil) translation
* Wed May  7 2025 Richard Rahl <rrahl0@opensuse.org>
- update to 1.76.0:
  * [Servers] Added ComicHubFree (EN)
  * [Servers] Asura Scans For Free (EN): Disabled
  * [Servers] Flame Comics (EN): Update
  * [Servers] Read Comic Online (EN): Update
  * [Servers] Team-X (AR): Update
  * [Servers] Terco Scans (EN):Update
  * [L10n] Updated translations
- remove convert-to-modern-colorthief.patch, upstreamed accepted PR
* Fri Apr  4 2025 Richard Rahl <rrahl0@opensuse.org>
- update to 1.75.0:
  * [Servers] ريبر العربي (AR): Disabled
  * [Servers] 3asq (AR): Disabled
  * [Servers] Dango Scan (pt_BR): Update
  * [Servers] DB New Hope (EN/ES/FR): Update
  * [Servers] Dynasty Reader (EN): Update
  * [Servers] EZmanga (EN): Ignored chapters with price
  * [Servers] Mangago (EN): Update
  * [Servers] Mangaowl (EN): Update
  * [Servers] MangaReader (EN): Update
  * [Servers] MangaWorld (IT): Update
  * [Servers] Manhwa Hentai (EN): Disabled
  * [Servers] Mint Manga (RU): Disabled
  * [Servers] Nazarick Scan (pt_BR): Update
  * [Servers] PhenixScans (FR): Update
  * [Servers] Reaper Scans (EN): Update
  * [Servers] Terco Scans (EN): Update
  * [Servers] Tres Daos (ES): Update
  * [Servers] View Comics (EN): Update
  * [Servers] Xoxocomics (EN): Update
  * [L10n] Updated French and Russian translations
* Fri Mar 28 2025 Richard Rahl <rrahl0@opensuse.org>
- update to 1.74.0:
  * [Library] Fixed inconsistent background color introduced in previous version
  * [Servers] Aurora Scan (pt_BR): Disabled
  * [Servers] Noromax (ID): Update
  * [Servers] Tecno Scans (EN): Update
  * [Servers] Wicked Witch Scan (pt_BR): Disabled
  * [Servers] Up-to-date modules feature: an app restart is now required for a change to take effect (modules update or setting activation/deactivation)
  * [L10n] Updated Bulgarian, Czech, French, Russian and Ukrainian translations
* Fri Mar 21 2025 Richard Rahl <rrahl0@opensuse.org>
- update to 1.73.0:
  * [Library] Added ability to update with <Ctrl+r> shortcut
  * [Card] Info: Improved display of Genres using badges
  * [Servers] Added MangaBin (EN)
  * [Servers] Added Vortex Scans For Free (EN)
  * [Servers] Flame Comics (EN): Update
  * [Servers] Manhuaus (EN): Update
  * [Servers] Perf Scan (FR): Update
  * [Servers] Remanga (RU): Update
  * [L10n] Added Hungarian translation
- remove patch fix-quotes.patch, as the patch is not needed for
  python313
* Mon Mar 10 2025 Richard Rahl <rrahl0@opensuse.org>
- update to 1.72.0:
  * [Servers] Added Nix of Nothing (EN)
  * [Servers] Added Three Panel Soul (EN)
  * [Servers] Added Wild Life (EN)
  * [Servers] Cartel De Manhwas (ES): Update
  * [Servers] MangaNato (EN): Update
  * [Servers] Terco Scans (EN): Update
  * [Servers] Tres Daos (ES): Update
  * [Servers] Crunchyroll (EN): Disabled
  * [Servers] Iris Scanlator (pt_BR): Disabled
  * [Servers] ReaperScans (FR,ID,TR): Disabled
* Mon Mar  3 2025 Richard Rahl <rrahl0@opensuse.org>
- update to 1.71.0:
  * [Explorer] Global search: Added ability to cancel search
  * [Servers] Comic Fans (EN): Disabled
  * [Servers] Perf Scan (FR): Re-enabled
  * [Servers] MangaCrab (ES): Update
  * [Servers] TCB Scans (EN): Update
  * [Servers] Terco Scans (EN): Update
  * [Servers] Usagi (RU): Update
  * [Servers] Webtoon: Fixed covers
  * [L10n] Added Persian translation
  * [L10n] Updated French and Russian translations
- adjust license, as appdata.xml has a different license
- update runtime dependencies, according to requirements.txt
* Thu Feb 13 2025 Richard Rahl <rrahl0@opensuse.org>
- update to 1.70.0:
  * [Card] Chapters list: Added Scanlators filter
  * [Servers] Desu (RU): Update
  * [Servers] Lector manga: Re-enabled
  * [Servers] Read Comic Online (EN): Update
  * [L10n] Updated Dutch, French, Swedish and Tamil translations
- update to 1.69.0:
  * [Servers] EZmanga (EN): Update
  * [Servers] Manga Demon (EN): Update
  * [Servers] MangaHub (EN): Update
  * [Servers] MangaWorld (IT): Update
  * [Servers] Neko Scans (ES): Update
  * [Servers] Sinensistoon (pt_BR): Renamed SCtoon (fusion with Cerise Scan)
  * [Servers] Cerise Scan (pt_BR): Disabled
  * [Servers] MangaLife (EN): Disabled
  * [Servers] MangaSee (EN): Disabled
  * [L10n] Added Czech translation
* Mon Jan 27 2025 Richard Rahl <rrahl0@opensuse.org>
- update to 1.68.0:
  * [Reader] Webtoon pager: Fixed pages jumping on initialization
  * [Servers] Added Poseidon Scans (FR)
  * [Servers] Mangago (EN): Update
  * [L10n] Added Tamil translation
  * [L10n] Updated Chinese (Simplified) and Finnish translations
* Fri Jan 17 2025 Bernhard Wiedemann <bwiedemann@suse.com>
- Fix build without %%check (boo#1227364)
* Tue Jan 14 2025 Richard Rahl <rrahl0@opensuse.org>
- missed a second syntax error
* Tue Jan 14 2025 Richard Rahl <rrahl0@opensuse.org>
- update to 1.67.0:
  * [Reader] Paused pages animations when obscured
  * [Servers] Anteiku Scans (FR): Update
  * [Servers] Asura Scans For Free (EN): Update
  * [Servers] ED Scanlation (FR): Update
  * [Servers] EZmanga (EN): Update
  * [Servers] Kewn Scans (EN): Update
  * [Servers] MonkeyUser (EN): Update
  * [Servers] Pepper&Carrot: Update
  * [Servers] Starbound Scans (FR): Update
  * [Servers] Terco Scans (ES): Update
  * [Servers] Webtoon Hatti (TR): Update
  * [Servers] Rukav Inari (ES): Disabled
  * [Servers] MangaWeebs (EN): Disabled
  * [Servers] LSComic (EN): Disabled
  * [Servers] Hunlight Scans (EN): Disabled
  * [Servers] Mode Scanlator (pt_BR): Disabled
  * [Servers] Best Manga (RU): Disabled
  * [Servers] Atikrost (TR): Disabled
  * [Servers] Perf Scan (FR): Disabled
  * [L10n] Updated Bulgarian, German and Polish translations
- update to 1.66.0:
  * [Servers] Added Asura Scans For Free (EN)
  * [Servers] Asura Scans (EN): Update
  * [Servers] MangaDex: Ignored externals and empty chapters
  * [Servers] MangaDex: Added Genres filter
  * [Servers] MangaHub: Avoided exceeding API rate limiting
  * [Servers] MangaLib (RU): Update
  * [Servers] Mangareader (to): Fixed decoding of scrumbled images
  * [L10n] Updated Finnish, Portuguese (Brazil), Russian, Spanish, Swedish and Ukrainian translations
- fix build by escaping quotes, adding fix-quotes.patch (fixes boo#1234719)
- add rudimentary tests
* Fri Dec  6 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 1.65.0:
  * [Card] Added Unread chapters badge
  * [Card] Info: Updated Genres icon
  * [Servers] Added Manga Koleji (TR)
  * [Servers] Added Webtoon Hatti (TR)
  * [Servers] ComicExtra (EN): Disabled
  * [Servers] Flame Comics (EN): Update
  * [Servers] Mangago (EN): Update
  * [Servers] View Comics (EN): Update
  * [Servers] Webtoon TR: Update
  * [L10n] Updated French, Russian, Spanish and Ukrainian translations
* Tue Nov 26 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 1.64.0:
  * [Servers] Added Weeb Central (EN)
  * [Servers] Flame Comics (EN): Update
  * [Servers] Manga Demon (EN): Update
  * [Servers] Fr-Scan (FR): Disabled
  * [Servers] Manga Scan (FR): Disabled
  * [L10n] Updated French translation
* Mon Nov 18 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 1.63.0:
  * [Preferences] Servers settings: Added language indicator
  * [Reader] Fixed keyboard navigation bugs after changing reading mode
  * [Reader] Webtoon pager: Extended scrollable zone to all viewport
  * [Reader] Fixed unwanted display/hiding of cursor during keyboard navigation
  * [Servers] MangaReader: Added ES/ES_LA/PT/pt_BR languages support
  * [Servers] MangaReader (multi): Improved search by finally taking into
    account language
  * [Servers] Read Comic Online (EN): Update
  * [L10n] Updated Croatian and German translations
* Mon Nov 11 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 1.62.0:
  * [Tracking] Improved dialog size adjustment and handling of errors when query trackers
  * [Servers] Terco Scans (ES): Update
  * [Servers] Flame Comics (EN): Update
  * [Servers] Team-X (AR): Update
  * [Servers] SushiScan (FR): Update
  * [L10n] Updated Bulgarian translation
* Fri Nov  8 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 1.61.1:
  * Fixed bad chapter and volume numbers
- update to 1.61.0:
  * [Tracking] Improved search results
  * [Servers] Asura Scans (EN): Update
  * [Servers] ComicExtra (EN): Update
  * [Servers] Honey Manga (UK): Update
  * [Servers] Kewn Scans (EN): Update
  * [Servers] Manga-Tube (DE): Update
  * [Servers] MangaCrab (ES): Update
  * [Servers] Mint Manga (RU): Update
  * [Servers] Read Manga (RU): Update
  * [Servers] Reaper Scans (EN): Update
  * [Servers] Self Manga (RU): Update
  * [Servers] Tecno Scans (ES): Update
  * [L10n] Updated translations
* Fri Oct 18 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 1.60.0:
  * Added Tracking support (AniList, MyAnimeList)
  * [Servers] Anteiku Scans (FR): Update
  * [Servers] Asura Scans (EN): Update
  * [Servers] Cerise Scan (pt_BR): Update
  * [Servers] ED Scanlation (FR): Update
  * [Servers] EZmanga (EN): Update
  * [Servers] M440.in (ES): Update
  * [Servers] Manga Demon (EN): Update
  * [Servers] MangaFreak (EN): Update
  * [Servers] Mangago (EN): Update
  * [Servers] Manga-Tube (DE): Update
  * [Servers] Scanvf (FR): Fixed search
  * [Servers] Sinensistoon (pt_BR): Update
  * [Servers] Starbound Scans (FR): Update
  * [Servers] Tecno Scans (ES): Update
  * [Servers] Colored Manga (EN): Disabled
  * [Servers] Read Comics Free (EN): Disabled
  * Updated translations
* Wed Sep 18 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 1.59.0:
  * [UX] Added system accent colors support
  * [Explorer] Fixed Global search
  * [Servers] Bentoscan (FR): Disabled
  * [Servers] VF Scan (FR): Disabled
- new minimum requirement of libadwaita (1.6)
* Mon Sep 16 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 1.58.0:
  * Fixed display of covers in animated GIF format
  * Fixed memory leaks
  * [Servers] Added Manga Mana (FR)
  * [Servers] Tecno Scan (ES): Reenable
  * [Servers] Anteiku Scans (FR): Update
  * [Servers] ComicExtra (EN): Update
  * [Servers] ED Scanlation (FR): Update
  * [Servers] EZmanga (EN): Update
  * [Servers] Kewn Scans (EN): Update
  * [Servers] MangaCrab (ES): Update
  * [Servers] MangaWeebs (EN): Update
  * [Servers] Reaper Scans (EN): Update
  * [Servers] Scylla Comics (EN): Update
  * [Servers] Starbound Scans (FR): Update
  * [L10n] Update Portuguese (Brazil) translation
- update to 1.57.0:
  * [Reader] RTL/LTR/Vertical pager: Fixed <Ctrl+mouse wheel> zooming
  * [Servers] Argos Comics (PT): Update
  * [Servers] Flame Comics (EN): Update
  * [Servers] MangaHere (EN): Update
  * [Servers] Read Comic Online (EN): Update
* Fri Aug 30 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 1.56.0:
  * [Reader] Fixed display of long strip images
  * [Servers] Improved webview CAPTCHAs detection
  * [Servers] Improved webview Cloudflare challenges detection
  * [Servers] Atikrost (TR): Update
  * [Servers] Local: Improved cover generation
  * [Servers] Manga Demon (EN): Update
  * [Servers] MangaHere (EN): Update
  * [Servers] Night scans (EN): Update
  * [Servers] Read Comic Online (EN): Update
  * [Servers] SushiScan (FR): Update
  * [Servers] VF Scan (FR): Update
  * [Servers] Xoxocomics (EN): Update
  * [L10n] Updated Croatian and Russian translations
* Sun Aug 18 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 1.55.0:
  * [Card] Improved Resume
  * [Servers] Argos Comics (PT): Update
  * [Servers] Armoni Scans (TR): Update
  * [Servers] KomikLovers (ID): Update
  * [Servers] Manga Tube (DE): Update
  * [Servers] MangaWeebs (EN): Update
  * [Servers] Rawdevart (JA): Update
  * [Servers] Tres Daos (ES): Update
  * [Servers] View Comics (EN): Update
  * [L10n] Updated Hindi and Spanish translations
* Fri Aug 16 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 1.54.0:
  * [Preferences] Reader: Added Scaling Filter parameter
  * Fixed in-app notification position in fullscreen
  * [Servers] Added Anteiku Scans (FR
  * [Servers] Added ED Scanlation (FR)
  * [Servers] Added EZmanga (EN)
  * [Servers] Added Kewn Scans (EN)
  * [Servers] Added Starbound Scans (FR)
  * [L10n] Updated French translation
* Sat Aug 10 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 1.53.0:
  * [Card] Disabled Resume on empty chapters list
  * [Reader] Changed interpolation method used to resize images
  * [Reader] Improved Resume
  * [Servers] Asura Scans (EN): Re-enabled
  * [Servers] Colored Manga (EN): Re-enabled
  * [Servers] Asura Scans (EN): Update
  * [Servers] Hunlight Scans (EN): Update
  * [Servers] Manga Scan (FR): Update
  * [Servers] Reaper Scans (EN): Update
  * [Servers] Team-X (AR): Update
  * [Servers] Komga: Fixed synchronization
* Fri Aug  2 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 1.52.0:
  * [Servers] Improved webview to complete Cloudflare challenges
  * [Servers] Improved webview to support Google ReCAPTCHA completion
  * [Servers] ComicExtra (EN): Update
  * [Servers] Manga-Scantrad (FR): Update
  * [Servers] Mode Scanlator (pt_BR): Update
  * [Servers] Read Comic Online (EN): Update
  * [Servers] Asura Scans (EN): Disabled
  * [Servers] Mangas Origines (FR): Disabled
  * Updated French and Ukrainian translations
* Sat Jul 13 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 1.51.1:
  * [Servers] Fixed the page to complete Cloudflare challenges
  * [Servers] Japscan (FR): Disabled
  * [Servers] Neko Scans (ES): Disabled
  * Updated translations.
* Wed Jul 10 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 1.51.0:
  * [Servers] Read Comic Online (EN): Update
  * [Servers] Senpai Ediciones (ES): Update
  * [Servers] SushiScan (FR): Update
  * [L10n] Added Croatian translation
* Tue Jul  2 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 1.50.0:
  * [Servers] Perf Scan (FR): Update
  * [Servers] Local: Several bug fixes and improvements
  * [Servers] Manga Demon (EN): Update
  * [Servers] MangaWorld (IT): Update
  * [Servers] TCB Scans (EN): Update
  * [Servers] FleksyScans (EN): Disabled
* Sun Jun 23 2024 Richard Rahl <rrahl0@disroot.org>
- update to 1.49.0:
  * [Servers] Fixed the page to complete Cloudflare challenges
  * [Servers] Argos Comics (pt_BR): Update
  * [Servers] MangaHub (EN): Update
  * [Servers] PhenixScans (FR): Update
  * [Servers] TCB Scans (EN): Update
  * [Servers] Ragna Scan (ES): Disabled
  * [Servers] Tecno Scan (ES): Disabled
  * [L10n] Updated Turkish translation
* Sun Jun 16 2024 Richard Rahl <rrahl0@disroot.org>
- update to 1.48.1:
  * Fixed backdrop bug
  * Local: Fixed wrong location of cover files
  * Luratoon Scan (pt_BR): Disabled
- update to 1.48.0:
  * Continuously updated servers modules
  * Added MangaFire (EN/ES/ES_LA/FR/JA/PT/pt_BR)
  * Reenabled Argos Comics (PT)
  * Flame Comics (EN): Update
  * Fr-Scan (FR): Update
  * Luratoon Scan (pt_BR): Update
  * MangaCrab (ES): Update
  * MangaWorld (IT): Update
  * Manga/in/ua (UK): Update
  * Added Swedish translation
  * Updated Arabic, French, German, Portuguese (Brazil), Spanish and Ukrainian translations
* Wed May 22 2024 Richard Rahl <rrahl0@disroot.org>
- update to 1.47.0:
  * [Reader] Added navigation with J and K keyboard keys
  * [Servers] Added Aurora Scan (pt_BR)
  * [Servers] Added Bentoscan (FR)
  * [Servers] Added Cerise Scan (pt_BR)
  * [Servers] Added Dango Scan (pt_BR)
  * [Servers] Added Luratoon Scan (pt_BR)
  * [Servers] Added Manga Reader (cc) [EN]
  * [Servers] Added Manga Scan (FR)
  * [Servers] Added Nazarick Scan (pt_BR)
  * [Servers] Added RF Dragon Scan (pt_BR)
  * [Servers] Added Scanvf (FR)
  * [Servers] Added Sinensistoon (pt_BR)
  * [Servers] Added Wicked Witch Scan (pt_BR)
  * [Servers] Hunlight Scans (EN): Reenabled
  * [Servers] MangaDex: Improved Latest Updates fetching
  * [Servers] Mangago (EN): Update
  * [Servers] Manhwa Hentai (EN): Update
  * [Servers] NHentai (EN/ZH/JA): Update
  * [Servers] Night scans (EN): Update
  * [Servers] Perf Scan (FR): Update
  * [Servers] Tecno Scan (ES): Update
  * [Servers] Tres Daos (ES): Update
  * [Servers] Union Mangás (PT): Disabled
- add new runtime dependency python3-pillow-heif
* Sat May 18 2024 Richard Rahl <rrahl0@disroot.org>
- update convert-to-modern-colorthief.patch as python-modern-colorthief got
  a complete rewrite in rust
* Thu May 16 2024 Richard Rahl <rrahl0@disroot.org>
-update to version 1.46.0:
  * [Webview] Fixed exiting when there is no Cloudflare challenge
  * [Servers] Added MangaCrab (ES)
  * [Servers] Comic Book Plus (EN): Update
  * [Servers] Mode Scanlator (pt_BR): Update
  * [Servers] Rawdevart (JA): Update
  * [Servers] Reaper Scans (EN): Update
  * [Servers] ShadowMangas (ES): Update
  * [Servers] Tecno Scan (ES): Update
  * [Servers] JManga (JA): Disabled
  * [L10n] Updated Chinese (Traditional), Dutch, German, Hindi, Italian and
    Turkish translations
- update to version 1.45.0:
  * fixes a bug that prevented some server logos from being displayed
  * [Webview] Improved Cloudflare user challenge completion
  * [Servers] Added Existential Comics (EN)
  * [Servers] Added Manga Demon (EN)
  * [Servers] Added MangaWeebs (EN)
  * [Servers] Added Webtoon TR
  * [Servers] Armoni Scans (Asura Scans TR): Reenabled
  * [Servers] Atikrost (TR): Reenabled
  * [Servers] Mangago (EN): Update
  * [Servers] MangaFreak (EN): Update
  * [Servers] Nine Manga (EN/PT_BR/DE/ES/FR/IT/RU): Update
  * [L10n] Added Vietnamese translation
  * [L10n] Updated French, German, Portuguese, Spanish and Russian
    translations
- update to version 1.44.0:
  * [Servers] Added Cartel De Manhwas (ES)
  * [Servers] Added F/OSS Comics (EN)
  * [Servers] Added Mode Scanlator (pt_BR)
  * [Servers] Added Neko Scans (ES)
  * [Servers] Added Ragna Scan (ES)
  * [Servers] Added Raiki Scan (ES)
  * [Servers] Added Rukav Inari (ES)
  * [Servers] Added Ryujinmanga (ES)
  * [Servers] Added Senpai Ediciones (ES)
  * [Servers] Added ShadowMangas (ES)
  * [Servers] Added SkyMangas (ES)
  * [Servers] Added Tecno Scan (ES)
  * [Servers] Added Tres Daos (ES)
  * [Servers] Read Manga, Mint Manga, Self Manga (RU): Update
  * [Servers] Tapas (EN): Update
  * [L10n] Added Hindi translation
  * [L10n] Updated Dutch, French and Indonesian translations
- update to version 1.43.0:
  * Improved downloads and covers display speed
  * [Servers] Added Comic Fans (EN)
  * [Servers] Added FleksyScans (EN)
  * [Servers] Added Iris Scanlator (pt_BR)
  * [Servers] Added KomikLovers (ID)
  * [Servers] Added Neromax (ID)
  * [Servers] Added Scylla Comics (EN)
  * [Servers] Added SushiScan (FR)
  * [Servers] Added VF Scan (FR)
  * [Servers] Legacy Scans (FR): Update
  * [Servers] Lelscan-VF (FR): Update
  * [Servers] TCB Scans (EN): Update
  * [L10n] Updated French translation
- update to version 1.42.0:
  * [Explorer] Search: Improved covers rendering
  * [Updater] Don't attempt to auto-download chapters when a Local source has an update
  * [Servers] Added DB New Hope (EN/ES/FR/RU/ZH_Hans)
  * [Servers] Added JManga (JA)
  * [Servers] Added MangaZin (EN)
  * [Servers] Added Read Comics Free (EN)
  * [Servers] Apoll Comics (ES): Update
  * [Servers] Mangalek (AR): Update
  * [Servers] View Comics (EN): Update
  * [Servers] Xoxocomics (EN): Update (new site)
  * [Servers] Bilibili Comics (EN/ES/FR/ID): Disabled
  * [L10n] Updated Finnish, Russian, Spanish and Turkish translations
* Mon Apr  1 2024 jun wang <jgwang@suse.com>
- Update to version 1.41.1
  * changes from 1.41.1
    + A regression in Explorer, pinned servers list was no longer
    cleared when it was refreshed
    + Wrong chapters order in Perf Scan (FR) server
    + [Servers] Added ComicExtra (EN)
    + [Servers] Perf Scan (FR): Update
    + [Servers] Mangas.in (ES: Update
    + [Servers] Reaper Scans (EN): Update
    + [L10n] Updated French, Russian, Spanish and Turkish
    translations
  * changes from 1.40.1
    + [UX] Refined visuals taking advantage of the new
    capabilities of GNOME 46
    + [Servers] Added Lelmanga (FR)
    + [Servers] Added Lelscan (FR)
    + [Servers] Added Night scans (EN)
    + [Servers] Comic Book Plus (EN): Fixed search
    + [Servers] MANGA Plus by SHUEISHA: Update
    + [Servers] MangaDex: Added Tags filter
    + [Servers] MangaLib (RU): Update
    + [Servers] Mangaowl (EN): Update
    + [Servers] Jpmangas (FR): Disabled
    + [Servers] Reaper Scans (pt_BR): Disabled
    + [Servers] Scan FR: Disabled
    + [Servers] Scan Manga (FR): Disabled
    + [L10n] Updated French, Russian, Spanish and Turkish
    translations
* Fri Mar  8 2024 Richard Rahl <rrahl0@proton.me>
- switch runtime dep python-typing-extensions to python-typing_extensions
* Fri Mar  8 2024 Richard Rahl <rrahl0@proton.me>
- require at least python-pure-protobuf 3.0.0
- add dependency to fix Komikku
* Sat Mar  2 2024 Richard Rahl <rrahl0@proton.me>
- update to 1.39.0:
  * Add an indicator when an partial update is in progress
  * Add Mangago
* Mon Feb 19 2024 Richard Rahl <rrahl0@proton.me>
- update to 1.38.1:
  * fixes a regression in Updater, where a "no new chapter" for notification
    was sent for every manga which didn't have updates
* Fri Feb 16 2024 Richard Rahl <rrahl0@proton.me>
- update to 1.38.0:
  * Improved error notification
  * Improved notifications
  * Prevent manga update from being scheduled while it's being updated
* Fri Feb  2 2024 Richard Rahl <rrahl0@proton.me>
- switch over to download_files to simplify packaging
- update to 1.37.1
  * Improve the Webview
* Tue Jan 30 2024 Richard Rahl <rrahl0@proton.me>
- update to 1.37.0
  * Added an indicator when an update is in progress
  * Added Pull-to-Update feature
  * Updated disk usage when one or more chapters are reset
  * Fixed typo error causing overload
  * Fixed "Report an Issue" link
  * Some improvements to speed up HTML pages parsing
* Fri Jan 26 2024 Richard Rahl <rrahl0@proton.me>
- update to 1.36.0
  * RTL/LTR/Vertical pager: Speed up white borders cropping
  * updated sources
* Wed Jan 24 2024 Richard Rahl <rrahl0@proton.me>
- initial packaging
